build

package
v0.0.0-...-011f561 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 9, 2026 License: Apache-2.0, BSD-3-Clause Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Target

type Target struct {
	// Srcs is the list of C, C++, or Rust files (determined by file extension)
	// that are built into the target.
	Srcs []string `json:"srcs,omitempty"`
	// Hdrs is the list public headers that should be available to external
	// projects using this target.
	Hdrs []string `json:"hdrs,omitempty"`
	// InternalHdrs is the list of internal headers that should be available to
	// this target, as well as any internal targets using this target.
	InternalHdrs []string `json:"internal_hdrs,omitempty"`
	// Asm is the a list of assembly files to be passed to a gas-compatible
	// assembler.
	Asm []string `json:"asm,omitempty"`
	// Nasm is the a list of assembly files to be passed to a nasm-compatible
	// assembler.
	Nasm []string `json:"nasm,omitempty"`
	// Data is a list of test data files that should be available when the test is
	// run.
	Data []string `json:"data,omitempty"`
}

A Target is a build target for consumption by the downstream build systems. All pre-generated files are baked input its source lists.

Jump to